-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------

function CovertAssault:StartActivity()
    	print("START! -- CovertAssault:StartActivity()!");
    	self.AreaTimer = Timer();
    	self.StepTimer = Timer();
	self.braindead = {};
	self.CPUBrain = nil;
	
	self.Sniper = SceneMan.Scene:GetArea("Sniper");
	self.Assault = SceneMan.Scene:GetArea("Assault");
	self.Heavy = SceneMan.Scene:GetArea("Heavy");
	
	self.GunListSniper = { "Heavy Sniper Rifle" };
	self.GunListAssault = { "Assault Rifle", "Compact Assault Rifle" };
	self.GunListHeavy = { "Gatling Gun","Auto Cannon","Revolver Cannon" };
    	--------------------------
    	-- Set up teams

    	-- Team 2 is always CPU
    	self.CPUTeam = Activity.TEAM_2;
    
    	--------------------------
    	-- Set up players

    for player = 0, self.PlayerCount - 1 do
        -- Check if we already have a brain assigned
        if not self:GetPlayerBrain(player) then
	    self.braindead[player] = false;
            local brain = CreateAHuman("Brain Robot");
            brain.Pos = Vector(250,1050-player*24);
            -- Let the spawn into the world, passing ownership
            MovableMan:AddActor(brain);			
			-- Set the brain to Sentry mode so it doesn't try to leave on you.
			brain.AIMode = Actor.AIMODE_SENTRY;
            -- Set the found brain to be the selected actor at start
            self:SetPlayerBrain(brain, player);
            SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
            self:SetLandingZone(self:GetPlayerBrain(player).Pos, player);
            -- Set the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
            self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
        end
    end

    -- Set up AI modes for the Actors that have been added to the scene by the scene definition
    for actor in MovableMan.AddedActors do
        if actor.Team == self.CPUTeam then
			actor.AIMode = Actor.AIMODE_SENTRY;
		if actor.PresetName == "Brain Robot" then
		self.CPUBrain = actor;
		end
		if self.Sniper:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListSniper[math.random(#self.GunListSniper)],"Coalition.rte"));
		end
		if self.Assault:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListAssault[math.random(#self.GunListAssault)],"Coalition.rte"));
		end
		if self.Heavy:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListHeavy[math.random(#self.GunListHeavy)],"Coalition.rte"));
		end
		end
	end
    -- Set the team's funds to 1000 oz.
    if self.Difficulty <= GameActivity.CAKEDIFFICULTY then
		self:SetTeamFunds(10000, Activity.TEAM_1);
	elseif self.Difficulty <= GameActivity.EASYDIFFICULTY then
		self:SetTeamFunds(1000, Activity.TEAM_1);
	elseif self.Difficulty <= GameActivity.MEDIUMDIFFICULTY then
		self:SetTeamFunds(500, Activity.TEAM_1);
	elseif self.Difficulty <= GameActivity.HARDDIFFICULTY then
		self:SetTeamFunds(250, Activity.TEAM_1);
	elseif self.Difficulty <= GameActivity.NUTSDIFFICULTY then
		self:SetTeamFunds(150, Activity.TEAM_1);
	elseif self.Difficulty <= GameActivity.MAXDIFFICULTY then
		self:SetTeamFunds(100, Activity.TEAM_1);
	end

	FrameMan:SetScreenText("Assasinate Coalition Commander to take over this base.", 0, 0, -1, false);
    --------------------------
    -- Set up tutorial
    
    self.AreaTimer:Reset();
    self.StepTimer:Reset();
    
end

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------

function CovertAssault:PauseActivity(pause)
    print("PAUSE! -- CovertAssault:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------

function CovertAssault:EndActivity()
    print("END! -- CovertAssault:EndActivity()!");
end

-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------

function CovertAssault:UpdateActivity()
    	-- Clear all objective markers, they get re-added each frame
    	self:ClearObjectivePoints();
	if not (self.ActivityState == Activity.OVER) then
    		--------------------------
    		-- Iterate through all human players
		for player = 0, self.PlayerCount - 1 do
        		-- The current player's team
        		local team = self:GetTeamOfPlayer(player);
        		-- Make sure the game is not already ending
            		-- Check if any player's brain is dead
            		local brain = self:GetPlayerBrain(player);
            		if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
                		self:SetPlayerBrain(nil, player);
                		-- Try to find a new unasigned brain this player can use instead, or if his old brain entered a craft
                		local newBrain = MovableMan:GetUnassignedBrain(team);
                		-- Found new brain actor, assign it and keep on truckin'
                		if newBrain and self.braindead[player] == false then
                	    		self:SetPlayerBrain(newBrain, player);
                	    		self:SwitchToActor(newBrain, player, team);
                		else
                    			FrameMan:SetScreenText("Your brain has been lost!", player, 333, -1, false);
					self.braindead[player] = true;
                    			-- Now see if all brains of self player's team are dead, and if so, end the game
                    			--if not MovableMan:GetClosestBrainActor(team) then
                        		self.WinnerTeam = self:OtherTeam(team);
                        		ActivityMan:EndActivity();
                    			--end
                		end
            		else
                		-- Update the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
                		self:SetObservationTarget(brain.Pos, player)
        		end
		end
        -- Game over, show the appropriate messages until a certain time
        elseif not self.GameOverTimer:IsPastSimMS(self.GameOverPeriod) then
		for player = 0, self.PlayerCount - 1 do
        		local team = self:GetTeamOfPlayer(player);
        		-- TODO: make more appropriate messages here for run out of funds endings
            		if team == self.WinnerTeam then
                		FrameMan:SetScreenText("Mission Completed!", player, 0, -1, false);
            		else
                		FrameMan:SetScreenText("Your brain has been lost!", player, 0, -1, false);
            		end
		end
	end
    	-- Mark the enemy brain.
	if MovableMan:IsActor(self.CPUBrain) then
	    self:AddObjectivePoint("Assasinate", self.CPUBrain.AboveHUDPos+Vector(0,-16), Activity.TEAM_1, GameActivity.ARROWDOWN);
	else
	    --If it doesn't exist, it's gone!  Player wins!
	    self.WinnerTeam = Activity.TEAM_1;
	    ActivityMan:EndActivity();
	end

      	 -- Sort the objective points
      	self:YSortObjectivePoints();
end